Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .alias import Alias, alias

9 from .beautify import beautify

10 from .binary_config import BinaryConfig, BinaryField

11 from .cls import TypedConfig, TypedMapping, TypedMutableMapping, update

12 from .core import (

13 check_and_convert_data,

14 convert_config,

15 ensure_types,

16 load_data,

17 load_into,

18 load_into_class,

19 load_into_instance,

20)

21 from .dump import asbytes, asdict, asjson, astoml, asyaml

22 from .helpers import all_annotations, check_type

23 from .loaders import register_loader as loader

24 from .postpone import postpone

25 from .singleton import Singleton, SingletonMeta

26 from .type_converters import register_converter as converter

27

28 __all__ = [

29 # beautify,

30 "beautify",

31 # binary

32 "BinaryConfig",

33 "BinaryField",

34 # cls

35 "TypedConfig",

36 "TypedMapping",

37 "TypedMutableMapping",

38 "update",

39 # singleton

40 "Singleton",

41 "SingletonMeta",

42 # core

43 "check_and_convert_data",

44 "convert_config",

45 "ensure_types",

46 "load_data",

47 "load_into",

48 "load_into_class",

49 "load_into_instance",

50 # helpers

51 "all_annotations",

52 "check_type",

53 # postpone

54 "postpone",

55 # dump

56 "asbytes",

57 "asdict",

58 "astoml",

59 "asyaml",

60 "asjson",

61 # register

62 "loader",

63 "converter",

64 # alias

65 "alias",

66 "Alias",

67]